@@ -14,6 +14,11 @@ from utils import get_sample, is_apple_m1, is_osx, is_x86_64, sign, chmod_exe, i
 
 lief.logging.set_level(lief.logging.LEVEL.INFO)
 
+def align_to(value, alignment):
+    # llvm::alignTo
+    assert (alignment & (alignment - 1)) == 0 # is power of two
+    return (value + alignment - 1) & ~(alignment - 1)
+
 def dyld_check(path: str):
     dyld_info_path = "/usr/bin/dyld_info"
     if not pathlib.Path(dyld_info_path).exists():
@@ -160,6 +165,9 @@ def test_add_section_id(tmp_path):
     original = lief.MachO.parse(bin_path.as_posix()).at(0)
     output = f"{tmp_path}/test_add_section_id.id.bin"
 
+    checked, err = lief.MachO.check_layout(original)
+    assert checked, err
+
     # Add 50 sections
     for i in range(50):
         section = lief.MachO.Section(f"__lief_{i}", [0x90] * 0x100)
@@ -180,6 +188,52 @@ def test_add_section_id(tmp_path):
         print(stdout)
         assert re.search(r'uid=', stdout) is not None
 
+def test_extend_section_1(tmp_path):
+    """ This test calls add_section followed by extend_section repeatedly.
+    """
+    bin_path = pathlib.Path(get_sample("MachO/MachO64_x86-64_binary_id.bin"))
+    original = lief.MachO.parse(bin_path.as_posix()).at(0)
+    output = f"{tmp_path}/test_extend_section.bin"
+
+    text_segment = original.get_segment("__TEXT")
+
+    for i in range(9, -1, -1):
+        section = lief.MachO.Section(f"__lief_{i}")
+        section.alignment = i
+        section = original.add_section(text_segment, section)
+        assert original.extend_section(section, 1 << section.alignment)
+
+    original.write(output)
+    new = lief.MachO.parse(output).at(0)
+
+    checked, err = lief.MachO.check_layout(new)
+    assert checked, err
+
+def test_extend_section_2(tmp_path):
+    """ This test makes multiple calls to add_section, and then it
+        extends each added section using extend_section.
+    """
+    bin_path = pathlib.Path(get_sample("MachO/MachO64_x86-64_binary_id.bin"))
+    original = lief.MachO.parse(bin_path.as_posix()).at(0)
+    output = f"{tmp_path}/test_extend_section.bin"
+
+    text_segment = original.get_segment("__TEXT")
+
+    sections = []
+    for i in range(3):
+        section = lief.MachO.Section(f"__lief_{i}")
+        section.alignment = 2 # 2^2 == 4 bytes
+        sections.append(original.add_section(text_segment, section))
+
+    for section in sections:
+        assert original.extend_section(section, 1000)
+
+    original.write(output)
+    new = lief.MachO.parse(output).at(0)
+
+    checked, err = lief.MachO.check_layout(new)
+    assert checked, err
+
 @pytest.mark.skipif(is_github_ci(), reason="sshd does not work on Github Action")
 def test_add_section_ssh(tmp_path):
     bin_path = pathlib.Path(get_sample("MachO/MachO64_x86-64_binary_sshd.bin"))
@@ -598,6 +652,7 @@ def test_encryption_info(tmp_path: Path):
 
 
 def test_issue_1206(tmp_path: Path):
+    # c.f. https://github.com/lief-project/LIEF/issues/1206
     # c.f. https://github.com/lief-project/LIEF/issues/1173
     macho = lief.MachO.parse(get_sample("MachO/issue_1206.bin")).at(0)
 
@@ -606,3 +661,40 @@ def test_issue_1206(tmp_path: Path):
 
     new = lief.MachO.parse(output).at(0)
     assert lief.MachO.check_layout(new)[0]
+
+def test_issue_1204(tmp_path: Path):
+    macho = lief.MachO.parse(get_sample("MachO/lief-dwarf-plugin-darwin-arm64.dylib")).at(0)
+    macho.rpath.path += '/a/very/long/path/that/needs/expansion'
+    out = tmp_path / "out.macho"
+    macho.write(out.as_posix())
+
+    new = lief.MachO.parse(out).at(0)
+    lief.MachO.check_layout(new)
+    assert new.rpath.path == '@loader_path/../a/very/long/path/that/needs/expansion'
+
+    macho = lief.MachO.parse(get_sample("MachO/lief-dwarf-plugin-darwin-arm64.dylib")).at(0)
+    macho.rpath.path += '/a/very/long/path/that/needs/expansion/' + 'a' * (macho.available_command_space + 10)
+    rpath = macho.rpath.path
+    out = tmp_path / "out2.macho"
+    macho.write(out.as_posix())
+
+    new = lief.MachO.parse(out).at(0)
+    lief.MachO.check_layout(new)
+    assert new.rpath.path == rpath
+
+def test_issue_1236(tmp_path: Path):
+    macho = lief.MachO.parse(get_sample("MachO/libmamba.4.0.1.dylib")).at(0)
+
+    checked, err = lief.MachO.check_layout(macho)
+    assert checked, err
+
+    for cmd in macho.commands:
+        if isinstance(cmd, lief.MachO.DylibCommand):
+            cmd.name = "/Users/random" + cmd.name
+
+    output = tmp_path / "out.macho"
+    macho.write(output.as_posix())
+    new = lief.MachO.parse(output)
+
+    checked, err = lief.MachO.check_layout(new)
+    assert checked, err
